# Changelog

Release history for `hordelib`.

## v0.2.0 - 2023-04-08

### Added
- Horde hires_fix support.
- Add upscaler support.
- Add inpainting.
- Add outpainting.

## v0.1.0 - 2023-04-06

### Added
- Clip skip support.
- Adds "tox -e comfyui" command to run comfyui web app.
- Significant refactors and build changes.
- Safety Checker

### Fixed
- ComfyUI upgrades work correctly now.
- Various fixes for Horde Worker integration.

## v0.0.10 - 2023-04-03

### Added
- CLIP interrogation
- Model manager

## v0.0.9 - 2023-04-03

### Added
- Adds build helper to package and publish correctly.
- More thorough tests for ComfyUI install/downgrade/upgrade/etc
- Working Ci workflow for Github.

## v0.0.8 - 2023-04-02

### Fixed
- Try harder to resolve dependancy installation.

## v0.0.7 - 2023-04-02

### Fixed
- Include dependencies in the pypi package.

### Changed
- Updates the readme with a working example.

## v0.0.6 - 2023-04-02

### Fixed
- Just install the latest ComfyUI version.

## v0.0.5 - 2023-04-02

### Fixed
- Remove broken ComfyUI version check

## v0.0.4 - 2023-04-02

### Fixed
- Fix the ComfyUI installation process when used from pypi.

## v0.0.3 - 2023-04-02

### Added
- Adds initial basic support for horde text to image payloads.

### Fixed
- Correctly updates embedded ComfyUI dependency when required.

## v0.0.2 - 2023-04-02

### Added
- Adds stable diffusion hires fix pipeline.
- Workflow and code to load ComfyUI pipelines saved from the web UI.

## v0.0.1 - 2023-03-31

### Added
- Initial proof of concept.
